# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/story/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\Story\\": "packages/litecms/story/src",
            "Litecms\\Story\\Seeders\\": "packages/litecms/story/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Story\Providers\StoryServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Story'  => Litecms\Story\Facades\Story::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\Story\\Seeders\\StoryTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Story\Providers\StoryServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Story\Providers\StoryServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Story\Providers\StoryServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/story/{modulename}

**User**

    http://path-to-route-folder/user/story/{modulename}

**Public**

    http://path-to-route-folder/stories


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/story/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/story/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/story/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/story/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/story/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/story/{modulename}/{slug}
    METHOD: GET