<?php

namespace Litecms\Story\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Story\Http\Resources\StoryResource;
use Litecms\Story\Http\Resources\StoriesCollection;
use Litecms\Story\Scopes\CategoryPublicScope;
use Litecms\Story\Models\Category;

class CategoryPublicController extends BaseController
{

    /**
     * Show category's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Category::pushScope(new RequestScope())
            ->pushScope(new CategoryPublicScope())
            ->select('categories.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new CategoriesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('story::category.names'))
            ->view('story::public.category.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show category.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Category::findBySlug($slug);
        $data = new CategoryResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('story::category.name'))
            ->view('story::public.category.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
